Documentation
¶
Overview ¶
Package transforms provides Dofns for Beam jobs processing CQL.
Index ¶
Constants ¶
const BeamMetadata = `
library BeamMetadata version '1.0.0'
using FHIR version '4.0.1'
context Patient
define ID: Patient.id.value
`
BeamMetadata produces the ID when running the CQL.
Variables ¶
This section is empty.
Functions ¶
func ErrorsNDJSONSink ¶
ErrorsNDJSONSink writes processing errors to an NDJSON file for troubleshooting.
func FileToBundle ¶
func FileToBundle(ctx context.Context, file fileio.ReadableFile, emitBundle func(*bpb.Bundle), emitError func(*cbpb.BeamError))
FileToBundle returns a collection of FHIR R4 bundles and a collection of `ProcessingError` protos for files that could not be parsed into a bundle.
func NDJSONSink ¶
func NDJSONSink(ctx context.Context, output *cbpb.BeamResult, emitValue func(string), emitError func(*cbpb.BeamError))
NDJSONSink marshals BeamResult to JSON and writes it to a NDJSON file.
Types ¶
Click to show internal directories.
Click to hide internal directories.